#!/usr/bin/perl
#####################################################################
# Function: en.pm
#
#
# 概要:
# PG-REX 便利ツールから呼び出すメッセージの集まり
# JPN ロケール以外用
# 
# 特記事項:
# なし
#
#####################################################################
use warnings;
use strict;

use constant {

    PGREX_USAGE  => <<_PGREX_USAGE_,

pg-rex version 1.2

PG-REX operation tool

Usage:pg-rex [-f CrmFilepath][-n Nodename][-h][Operation]

    -f CrmFilepath,
       --file=CrmFilepath   reflect the crm file in the case of that the operation
                            is masterstart and first startup
    -n Nodename,
       --node=Nodename      operate PG-REX at node name
    -h, --help              show this help, then exit
    Operation               specify the operation of one of the following
                               masterstart : start as a Master
                               slavestart  : start as a Slave
                               stop        : stop

_PGREX_USAGE_

    PGREX_MS0001        => "The command \"Ctrl+C\" is invalid request.\n",
    PGREX_MS0002        => "Should specify an operation in the argument.\n",
    PGREX_MS0003        => "No such operation of \"[0]\".\n",
    PGREX_MS0004        => "Run the operation of \"[0]\".\n",

    MASTERSTART_USAGE  => <<_MASTERSTART_USAGE_,

pg-rex_master_start version 1.2

PG-REX Master start tool
This is executed on the node that will start as a Master.

Usage:pg-rex_master_start [-h][CrmFilePath]

    -h, --help       show this help, then exit
    CrmFilePath      reflect the crm file in the case of first startup

_MASTERSTART_USAGE_

    MASTERSTART_MS0001  => "The command \"Ctrl+C\" is invalid request.\n",
    MASTERSTART_MS0002  => "No such crm file specified in the argument.\n",
    MASTERSTART_MS0004  => "Failed to read crm file.\n",
    MASTERSTART_MS0007  => "[0]. Check Pacemaker has stopped\n",
    MASTERSTART_MS0008  => "…[NG]\n",
    MASTERSTART_MS0009  => "Pacemaker has started.\n",
    MASTERSTART_MS0010  => "…[OK]\n",
    MASTERSTART_MS0011  => "[0]. Check Master has not started on another node\n",
    MASTERSTART_MS0013  => "Master has started on another node.\n",
    MASTERSTART_MS0014  => "[0]. Check PGSQL lock file\n",
    MASTERSTART_MS0015  => "There is PGSQL lock file (\"[0]\").\n",
    MASTERSTART_MS0016  => "There are cib files in /var/lib/heartbeat/crm.\n".
                           "These are deleted so reflected the new configuration, but are you sure? (y/N) ",
    MASTERSTART_MS0017  => "Exit.\n",
    MASTERSTART_MS0018  => "[0]. Delete cib files in /var/lib/heartbeat/crm\n",
    MASTERSTART_MS0019  => "[0]. Starting Pacemaker\n",
    MASTERSTART_MS0020  => "[0]. Reflect crm file\n",
    MASTERSTART_MS0021  => "[0]-seconds timeout occurred while checking the startup of the Pacemaker.\n".
                           "Should check the status of Pacemaker with crm_mon command.\n",
    MASTERSTART_MS0022  => "[0]. Check Master has started\n",
    MASTERSTART_MS0023  => "Resource has failed while the startup of the Pacemaker.\n".
                           "Should check the status of Pacemaker with crm_mon command.\n",
    MASTERSTART_MS0024  => "[0]-seconds timeout occurred while checking the startup of the Pacemaker.\n".
                           "Should check the process of PostgreSQL with ps command whether PostgreSQL has started successfully.\n",
    MASTERSTART_MS0025  => "Failed to connect to PostgreSQL database.\n",
    MASTERSTART_MS0026  => "Master has started on the node ([0]).\n",
    MASTERSTART_MS0027  => "[0]. Check to be able to start up as a Master\n",
    MASTERSTART_MS0028  => "The value of pgsql-data-status on this node is \"[0]\".\n".
                           "Pacemaker cannot start as a Master unless this value is \"LATEST\" , or has been registered for reasons as first startup.\n",
    MASTERSTART_MS0029  => "root@[0]'s password:",
    MASTERSTART_MS0030  => "\nPassword has been entered.\n",
    MASTERSTART_MS0032  => "Failed to reflect crm file.\n".
                           "Should stop Pacemaker so check the content of \"[0]\".\n",
    
    MASTERSTART_MS0033  => "Should specify the parameter of \"[1]\" of ResourceID (\"[0]\") in crm file.\n",

    SLAVESTART_USAGE  => <<_SLAVESTART_USAGE_,

pg-rex_slave_start version 1.2

PG-REX Slave start tool
This is executed on the node that will start as a Slave.

Usage:pg-rex_slave_start [-h][-n][-f]

    -h, --help            show this help, then exit
    -n, --nobasebackup    start without taking a base backup from Master
    -f, --force           execute without contacts

_SLAVESTART_USAGE_

    SLAVESTART_MS0001   => "The command \"Ctrl+C\" is invalid request.\n",
    SLAVESTART_MS0004   => "[0]. Check Pacemaker has stopped\n",
    SLAVESTART_MS0005   => "…[NG]\n",
    SLAVESTART_MS0006   => "Pacemaker has started.\n",
    SLAVESTART_MS0007   => "…[OK]\n",
    SLAVESTART_MS0008   => "[0]. Check Check Master has started on another node\n",
    SLAVESTART_MS0010   => "Master has not started on another node.\n",
    SLAVESTART_MS0011   => "[0]. Check connecting to another node with IC-LAN\n",
    SLAVESTART_MS0012   => "No connection response.\n",
    SLAVESTART_MS0013   => "[0]. Check PGSQL lock file\n",
    SLAVESTART_MS0014   => "There is PGSQL lock file (\"[0]\").\n".
                           "In the case, this node may have previously started as a Master.\n".
                           "Should check whether you really want to start as a Slave.\n",
    SLAVESTART_MS0015   => "[0]. Taking a base backup from Master\n",
    SLAVESTART_MS0016   => "This node takes a base backup from Master.\n".
                           "Are you sure? (y/n) ",
    SLAVESTART_MS0017   => "Exit.\n",
    SLAVESTART_MS0018   => "Failed to execute readlink command.\n",
    SLAVESTART_MS0019   => "[0]. Synchronized with the archive directory on the master\n",
    SLAVESTART_MS0020   => "[0]. Delete files in /var/lib/heartbeat/crm\n",
    SLAVESTART_MS0021   => "[0]. Starting Pacemaker\n",
    SLAVESTART_MS0022   => "[0]. Check Slave has started\n",
    SLAVESTART_MS0023   => "[0]-seconds timeout occurred while checking the startup of the Pacemaker.\n".
                           "Should check the status of Pacemaker with crm_mon command.\n",
    SLAVESTART_MS0024   => "Resource has failed while the startup of the Pacemaker.\n".
                           "Should check the status of Pacemaker with crm_mon command.\n",
    SLAVESTART_MS0025   => "[0]-seconds timeout occurred while checking the startup of the Pacemaker.\n".
                           "Should check the process of PostgreSQL with ps command whether PostgreSQL has started successfully.\n",
    SLAVESTART_MS0026   => "Failed to connect to PostgreSQL database.\n",
    SLAVESTART_MS0027   => "Wal sender process of Master is not starting.\n",
    SLAVESTART_MS0028   => "PostgreSQL has started as a Slave in synchronous replication.\n",
    SLAVESTART_MS0029   => "Slave has started on the node ([0]).\n",
    SLAVESTART_MS0030   => "root@[0]'s password:",
    SLAVESTART_MS0031   => "\nPassword has been entered.\n",
    SLAVESTART_MS0033   => "No such device specified in bcast or ucast in ha.cf on another node.\n",

    STOP_USAGE  => <<_STOP_USAGE_,

pg-rex_stop version 1.2

PG-REX stop tool
This is executed on the node that will stop.

Usage:pg-rex_stop [-h]

    -h, --help       show this help, then exit

_STOP_USAGE_

    STOP_MS0001         => "The command \"Ctrl+C\" is invalid request.\n",
    STOP_MS0004         => "Pacemaker has already stopped.\n",
    STOP_MS0005         => "PostgreSQL has already stopped.\n".
                           "Stopping Pacemaker.\n",
    STOP_MS0006         => "Stopping Master.\n",
    STOP_MS0007         => "Stopping Slave.\n",
    STOP_MS0008         => "Slave has already started.\n".
                           "If you continue with this operation, then a failover occurs, but are you sure? (y/N) ",
    STOP_MS0009         => "Exit.\n",
    STOP_MS0010         => "1. Stopping Pacemaker\n",
    STOP_MS0011         => "…[OK]\n",
    STOP_MS0012         => "2. Check Pacemaker has stopped\n",
    STOP_MS0013         => "…[NG]\n",
    STOP_MS0014         => "[0]-seconds timeout occurred while checking the startup of the Pacemaker.\n".
                           "Should check these processes of PostgreSQL and Pacemaker with ps command whether they have started successfully.\n",
    STOP_MS0015         => "Pacemaker has stopped on the node ([0]).\n",
    STOP_MS0016         => "[0] has stopped on the node ([1]).\n",
    STOP_MS0017         => "Should specify the parameter of \"pgdata\" of ResourceID (\"[0]\") in cib.xml, or cannot check the status of PostgreSQL.\n".
                           "Work on the assumption that the status of PostgreSQL is already stopped.\n",

    DBCHECK_USAGE  => <<_DBCHECK_USAGE_,

pg-rex_dbcluster_check version 1.2

Check database cluster whether taking a base backup when starting as a Slave.

Usage:pg-rex_dbcluster_check [-h]

    -h, --help      show this help, then exit

_DBCHECK_USAGE_

    DBCHECK_MS0001      => "The command \"Ctrl+C\" is invalid request.\n",
    DBCHECK_MS0002      => "**** Ready to run ****\n",
    DBCHECK_MS0003      => "[0]. Read config file and get both node names\n",
    DBCHECK_MS0005      => "…[OK]\n\n",
    DBCHECK_MS0006      => "[0]. Check Pacemaker has stopped\n",
    DBCHECK_MS0007      => "…[NG]\n",
    DBCHECK_MS0008      => "Pacemaker has started.\n",
    DBCHECK_MS0009      => "[0]. Check Master has started  on another node\n",
    DBCHECK_MS0011      => "Master is not starting on another node.\n",
    DBCHECK_MS0012      => "**** Check whether there is a need to take a base backup ****\n",
    DBCHECK_MS0013      => "[0]. Check that it is not first startup\n",
    DBCHECK_MS0014      => "Could not find cib.xml (\"[0]\").\n",
    DBCHECK_MS0015      => "[0]. Check database cluster\n",
    DBCHECK_MS0017      => "Could not find postgresql.conf (\"[0]\").\n",
    DBCHECK_MS0018      => "[0]. Check PGSQL lock file\n",
    DBCHECK_MS0019      => "There is PGSQL lock file (\"[0]\").\n".
                           "In the case, this node may have previously started as a Master.\n".
                           "Cannot start as a Slave without taking a base backup.\n",
    DBCHECK_MS0020      => "[0]. Check the status of database cluster on both nodes\n",
    DBCHECK_MS0021      => "Database identifier on this node is different from another ([0] != [1]).\n",
    DBCHECK_MS0022      => "TimeLineID on this node is larger than another ([0] > [1]).\n",
    DBCHECK_MS0023      => "The location of xlog on this node is progressing than another ([0] > [1]).\n",
    DBCHECK_MS0024      => "The content of history file (\"[0]\") of TimeLineID on this node is different from another.\n",
    DBCHECK_MS0025      => "There are no history that has passed through TimeLineID on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
    DBCHECK_MS0026      => "There are no history that has passed through the location of xlog on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
    DBCHECK_MS0027      => "You do not need to take a base backup when start as a Slave.\n".
                           "But, the current database cluster is a cluster of time at \"[0]\".\n".
                           "Should try to take a base backup if this is very old.\n",
    DBCHECK_MS0028      => "You must take a base backup when start as a Slave.\n",
    DBCHECK_MS0029      => "root@[0]'s password:",
    DBCHECK_MS0030      => "\nPassword has been entered.\n",

    ARCHDELETE_USAGE  => <<_ARCDELETE_USAGE_,

pg-rex_archivefile_delete version 1.2

PG-REX remove archive log tool

Usage:pg-rex_archivefile_delete [-m][-r][-f][-h][[Hostname:]BasebackupPath]

    -m, --move      execute as a mv mode
    -r, --remove    execute as a rm mode
       (You must specify either mv mode or rm.)
    -f, --force     execute without contacts
    -h, --help      show this help, then exit
    Hostname        the hostname of remote server that exists a base backup
    BasebackupPath  the fullpath of remote server that exists a base backup
        Caution:  You will not be able to use a base backup older than one specified.

_ARCDELETE_USAGE_

    ARCHDELETE_MS0001   => "The command \"Ctrl+C\" is invalid request.\n",
    ARCHDELETE_MS0002   => "Should specify mv mode or rm in the argument.\n",
    ARCHDELETE_MS0003   => "\n**** 1. Ready to run ****\n",
    ARCHDELETE_MS0004   => "Run mv mode.\n",
    ARCHDELETE_MS0005   => "Run rm mode.\n",
    ARCHDELETE_MS0006   => "The input format of the backup path is invalid : \"[0]\"\n",
    ARCHDELETE_MS0007   => "Please input a remote server name that has a base backup.\n".
                           "(If empty, set \"localhost\")\n".
                           "> ",
    ARCHDELETE_MS0008   => "The input format of the remote server is invalid : \"[0]\"\n",
    ARCHDELETE_MS0009   => "Please input a fullpath of the base backup.\n".
                           "(If empty, set no backup path.\n".
                           " In the case, you cannot use a base backup older than one specified because the archive log is removed.)\n".
                           "> ",
    ARCHDELETE_MS0010   => "The input format of the fullpath of ths base backup is invalid : \"[0]\"\n",
    ARCHDELETE_MS0011   => "Remote server \"[0]\", Backup path\"[1]\".\n".
                           "Are you sure? (y/N) : ",
    ARCHDELETE_MS0012   => "Exit.\n",
    ARCHDELETE_MS0013   => "Read config file.\n",
    ARCHDELETE_MS0015   => "Get both node names.\n",
    ARCHDELETE_MS0016   => "Read cib.xml.\n",
    ARCHDELETE_MS0018   => "Remove the archive log on the basis of the current database cluster on this node or another if you run without specifying the backup path.\n".
                           "Do you want to delete the archive log? (y/N) : ",
    ARCHDELETE_MS0019   => "\n**** 2. Get wal file names ****\n",
    ARCHDELETE_MS0020   => "Get first wal file name that needs to recovery from the backup specified.\n",
    ARCHDELETE_MS0021   => "No such directory (\"[0]\").\n",
    ARCHDELETE_MS0022   => "The format of fist line of the backup label file is invalid.\n",
    ARCHDELETE_MS0023   => " \"[0]\" \n",
    ARCHDELETE_MS0024   => "Get first wal file name that needs to recovery from the database cluster (\"[1]\") on this node (\"[0]\").\n",
    ARCHDELETE_MS0025   => "Failed to get first wal file name because the result of pg_controldata command is empty.\n",
    ARCHDELETE_MS0026   => "Get first wal file name that needs to recovery from the database cluster (\"[1]\") on another node (\"[0]\").\n",
    ARCHDELETE_MS0027   => "\n**** 3. Calculate the deletion target ****\n",
    ARCHDELETE_MS0028   => "No the deletion target.\n",
    ARCHDELETE_MS0029   => "Set \"[0]\" to the deletion target.\n",
    ARCHDELETE_MS0030   => "\n**** 4. Remove the archive log ****\n",
    ARCHDELETE_MS0031   => "Could not find the archive directory (\"[0]\").\n",
    ARCHDELETE_MS0032   => "Add \"[0]\" to the list of the deletion target.\n",
    ARCHDELETE_MS0033   => "The list of the deletion target is empty.\n",
    ARCHDELETE_MS0034   => "The directory where you want to move the archive log already exist.\n",
    ARCHDELETE_MS0035   => "Failed to creating the directory where you want to move the archive log.\n",
    ARCHDELETE_MS0036   => "Failed to change the owner of the directory where you want to move the archive log.\n",
    ARCHDELETE_MS0037   => "Create the directory where you want to move the archive log.\n",
    ARCHDELETE_MS0038   => "Failed to move the file (\"[0]\").\n",
    ARCHDELETE_MS0039   => " -- mv -- [0] \n",
    ARCHDELETE_MS0040   => "Succeed moving the archive log.\n".
                           "These are in the directory (\"[0]\").\n",
    ARCHDELETE_MS0041   => "Failed to remove the file (\"[0]\").\n",
    ARCHDELETE_MS0042   => " -- rm -- [0] \n",
    ARCHDELETE_MS0043   => "Succeed removing the archive log.\n",
    ARCHDELETE_MS0044   => "root@[0]'s password:",
    ARCHDELETE_MS0045   => "\nPassword has been entered.\n",

    COMMON_MS0001       => "Failed to execute crm_mon command.\n",
    COMMON_MS0003       => "Should specify the parameter of \"[1]\" of ResourceID (\"[0]\") in cib.xml.\n",
    COMMON_MS0004       => "Should specify [0] in config file.\n",
    COMMON_MS0005       => "Should specify Archive_dir of fullpath in config file.\n",
    COMMON_MS0006       => "Should specify STONITH which is setting either enable or disable in config file.\n",
    COMMON_MS0007       => "Should specify D-LAN_IPAddress which is setting two IPAddress separated by a comma in config file.\n",
    COMMON_MS0008       => "Failed to get the value of own IPAddress.\n",
    COMMON_MS0009       => "Should specify an IPAddress of this server in setting two IPAddress of D-LAN_IPAddress.\n",
    COMMON_MS0010       => "Should specify an IPAddress of another server in setting two IPAddress of D-LAN_IPAddress.\n",
    COMMON_MS0011       => "Failed to execute \"[0]\" command.\n",
    COMMON_MS0013       => "Failed to parse the location of xlog.\n",
    COMMON_MS0014       => "Failed to get the value by pg_controldata command.\n",
    COMMON_MS0015       => "Failed to get the name of another node.\n",
    COMMON_MS0016       => "Failed to connect to another node by ssh.\n",
    COMMON_MS0017       => "Failed to execute rsync command.\n",
    COMMON_MS0018       => "Failed to execute scp command.\n",
    COMMON_MS0019       => "Should specify bcast or ucast in ha.cf.\n",
    COMMON_MS0020       => "Should specify node in ha.cf.\n",
    COMMON_MS0021       => "Should specify VIP_SLAVE which is setting either enable or disable in config file.\n",
    COMMON_MS0022       => "Should specify STONITH_ResourceID which is setting two IPAddress separated by a comma in config file.\n",
    COMMON_MS0023       => "Failed to read cib.xml (\"[0]\").\n",
    COMMON_MS0024       => "Failed to read config file (\"[0]\").\n",
    COMMON_MS0025       => "Failed to read ha.cf (\"[0]\").\n",
    COMMON_MS0026       => "You are running in \"[0]\" user.\n".
                           "Should try again in root user.\n",

};

1;