#!/usr/bin/perl
#####################################################################
# Function: ja.pm
#
#
# 概要:
# PG-REX 便利ツールから呼び出すメッセージの集まり
# JPN ロケール用
# 
# 特記事項:
# なし
#
#####################################################################
use warnings;
use strict;

use constant {

    PGREX_USAGE  => <<_PGREX_USAGE_,

pg-rex version 1.2

PG-REX のオペレーションを実行するツール

Usage:pg-rex [-f CrmFilepath][-n Nodename][-h][Operation]

    -f CrmFilepath,
       --file=CrmFilepath   オペレーションが masterstart でかつ初回起動の場合、
                            crm ファイルのファイルパスを指定します
    -n Nodename,
       --node=Nodename      リモート先の PG-REX のオペレーションを行います
    -h, --help              Usage を表示し終了します
    Operation               以下のいずれかのオペレーションを指定します
                               masterstart : PG-REX を Master で起動する
                               slavestart  : PG-REX を Slave で起動する
                               stop        : PG-REX を停止する

_PGREX_USAGE_

    PGREX_MS0001        => "Ctrl+C は本プログラムでは無効です\n",
    PGREX_MS0002        => "引数にオペレーションを指定してください\n",
    PGREX_MS0003        => "オペレーションに \"[0]\" は存在しません\n",
    PGREX_MS0004        => "オペレーション \"[0]\" を実行します\n",

    MASTERSTART_USAGE  => <<_MASTERSTART_USAGE_,

pg-rex_master_start version 1.2

PG-REX を Master として起動するツール
Master として起動したいノードで実行する

Usage:pg-rex_master_start [-h][CrmFilePath]

    -h, --help       Usage を表示し終了します
    CrmFilePath      初回起動時のみ crm ファイルのファイルパスを指定します

_MASTERSTART_USAGE_
    
    MASTERSTART_MS0001  => "Ctrl+C は本プログラムでは無効です\n",
    MASTERSTART_MS0002  => "指定された crm ファイルが存在しません\n",
    MASTERSTART_MS0004  => "crm ファイルの読み込みに失敗したためスクリプトを終了します\n",
    MASTERSTART_MS0007  => "[0]. Pacemaker が起動していないことを確認\n",
    MASTERSTART_MS0008  => "…[NG]\n",
    MASTERSTART_MS0009  => "コマンド実行上のノードで Pacemaker が稼働しています\n".
                           "Master 起動処理を中止します\n",
    MASTERSTART_MS0010  => "…[OK]\n",
    MASTERSTART_MS0011  => "[0]. 稼働中の Master が存在していないことを確認\n",
    MASTERSTART_MS0013  => "別の系のマシンで Master が稼働中です\n".
                           "Master 起動処理を中止します\n",
    MASTERSTART_MS0014  => "[0]. 起動禁止フラグの存在を確認\n",
    MASTERSTART_MS0015  => "起動禁止フラグ \"[0]\" が存在するため Master の起動処理を中止します\n",
    MASTERSTART_MS0016  => "/var/lib/heartbeat/crm 配下に既に cib ファイルがあります\n".
                           "削除して反映しても宜しいでしょうか？ (y/N) ",
    MASTERSTART_MS0017  => "スクリプトを終了します\n",
    MASTERSTART_MS0018  => "[0]. /var/lib/heartbeat/crm 配下の cib ファイルを削除\n",
    MASTERSTART_MS0019  => "[0]. Pacemaker 起動\n",
    MASTERSTART_MS0020  => "[0]. crm ファイルの反映\n",
    MASTERSTART_MS0021  => "Pacemaker 起動確認処理のタイムアウト時間([0]秒)を経過したためスクリプトを終了します\n".
                           "crm_mon コマンドを用いて Pacemaker の状態を確認してください\n",
    MASTERSTART_MS0022  => "[0]. Master の起動確認\n",
    MASTERSTART_MS0023  => "Pacemaker の起動中にリソース故障が発生しました\n".
                           "crm_mon コマンドを用いて Pacemaker の状態を確認してください\n",
    MASTERSTART_MS0024  => "Pacemaker 起動確認処理のタイムアウト時間([0]秒)を経過したためスクリプトを終了します\n".
                           "ps コマンドを用いて PostgreSQL のプロセスが正常に起動されているかを確認してください\n",
    MASTERSTART_MS0025  => "PostgreSQL の DB に接続出来ません\n",
    MASTERSTART_MS0026  => "ノード([0])が Master として起動しました\n",
    MASTERSTART_MS0027  => "[0]. Master として稼働することが出来るかを確認\n",
    MASTERSTART_MS0028  => "コマンド実行ノードの pgsql-data-status の値が \"[0]\" になっています\n".
                           "pgsql-data-status が初回起動などでまだ登録されていない状態か \"LATEST\" か \"STREAMING|SYNC\" の値でないと\n".
                           "DB クラスタが最新でない可能性があるため、Master として稼働することが出来ません\n".
                           "Master 起動処理を中止します\n",
    MASTERSTART_MS0029  => "root@[0]'s password:",
    MASTERSTART_MS0030  => "\nパスワードが入力されました\n",
    MASTERSTART_MS0032  => "crm ファイルの Pacemaker への反映に失敗したためスクリプトを終了します\n".
                           "Pacemaker を停止し、[0]. の内容を確認して下さい\n",
    MASTERSTART_MS0033  => "crm ファイルにリソース ID \"[0]\" の \"[1]\" のパラメータが存在していません\n",

    SLAVESTART_USAGE  => <<_SLAVESTART_USAGE_,

pg-rex_slave_start version 1.2

PG-REX を Slave として起動するツール
Slave として起動したいノードで実行する

Usage:pg-rex_slave_start [-h][-n][-f]

    -h, --help            Usage を表示し終了します
    -n, --nobasebackup    Master の DB クラスタの取得・展開を行なわずに
                          Slave を起動します
    -f, --force           スクリプトの問い合わせ無しで実行します

_SLAVESTART_USAGE_
    
    SLAVESTART_MS0001   => "Ctrl+C は本プログラムでは無効です\n",
    SLAVESTART_MS0004   => "[0]. Pacemaker が起動していないことを確認\n",
    SLAVESTART_MS0005   => "…[NG]\n",
    SLAVESTART_MS0006   => "Pacemaker が稼働しています\n".
                           "Slave 起動処理を中止します\n",
    SLAVESTART_MS0007   => "…[OK]\n",
    SLAVESTART_MS0008   => "[0]. 稼働中の Master が存在していることを確認\n",
    SLAVESTART_MS0010   => "別の系のマシンで Master が稼働していません\n".
                           "Slave 起動処理を中止します\n",
    SLAVESTART_MS0011   => "[0]. IC-LAN が接続されていることを確認\n",
    SLAVESTART_MS0012   => "IC-LAN の接続応答がありません\n",
    SLAVESTART_MS0013   => "[0]. 起動禁止フラグの存在を確認\n",
    SLAVESTART_MS0014   => "起動禁止フラグ \"[0]\" が存在するため Slave の起動処理を中止します\n".
                           "前回停止時に Master として稼働していた可能性があるので Slave として起動していいかどうかを確認して下さい\n",
    SLAVESTART_MS0015   => "[0]. Master からベースバックアップ取得・展開\n",
    SLAVESTART_MS0016   => "ベースバックアップの取得・展開を行います\n".
                           "よろしいでしょうか？ (y/n) ",
    SLAVESTART_MS0017   => "スクリプトを終了します\n",
    SLAVESTART_MS0018   => "readlink コマンドの実行に失敗しました\n",
    SLAVESTART_MS0019   => "[0]. Master のアーカイブディレクトリと同期\n",
    SLAVESTART_MS0020   => "[0]. /var/lib/heartbeat/crm 配下のファイルを削除\n",
    SLAVESTART_MS0021   => "[0]. Slave の起動\n",
    SLAVESTART_MS0022   => "[0]. Slave の起動確認\n",
    SLAVESTART_MS0023   => "Pacemaker 起動確認処理のタイムアウト時間([0]秒)を経過したためスクリプトを終了します\n".
                           "crm_mon コマンドを用いて Pacemaker の状態を確認してください\n",
    SLAVESTART_MS0024   => "Pacemaker の起動中にリソース故障が発生しました\n".
                           "crm_mon コマンドを用いて Pacemaker の状態を確認してください\n",
    SLAVESTART_MS0025   => "Pacemaker 起動確認処理のタイムアウト時間([0]秒)を経過したのでスクリプトを終了します\n".
                           "ps コマンドを用いて PostgreSQL のプロセスが正常に起動されているかを確認してください\n",
    SLAVESTART_MS0026   => "PostgreSQL の DB に接続出来ません\n",
    SLAVESTART_MS0027   => "Master の wal sender プロセスが起動していません\n",
    SLAVESTART_MS0028   => "Slave の PostgreSQL が同期レプリケーションを開始していません\n",
    SLAVESTART_MS0029   => "ノード([0])が Slave として起動しました\n",
    SLAVESTART_MS0030   => "root@[0]'s password:",
    SLAVESTART_MS0031   => "\nパスワードが入力されました\n",
    SLAVESTART_MS0033   => "別の系のマシンで ha.cf の bcast(or ucast) に指定されたデバイスが見つかりません\n",

    STOP_USAGE  => <<_STOP_USAGE_,

pg-rex_stop version 1.2

PG-REX を停止するツール
停止したいノードで実行する

Usage:pg-rex_stop [-h]

    -h, --help       Usage を表示し終了します

_STOP_USAGE_
    
    STOP_MS0001         => "Ctrl+C は本プログラムでは無効です\n",
    STOP_MS0004         => "既に Pacemaker は停止しているため停止処理を終了します\n",
    STOP_MS0005         => "PostgreSQL が停止しています\n".
                           "Pacemaker を停止します\n",
    STOP_MS0006         => "Master を停止します\n",
    STOP_MS0007         => "Slave を停止します\n",
    STOP_MS0008         => "Slave がまだ起動しています\n".
                           "今停止すると F/O しますが本当に停止しても宜しいですか？ (y/N) ",
    STOP_MS0009         => "スクリプトを停止します\n",
    STOP_MS0010         => "1. Pacemaker 停止\n",
    STOP_MS0011         => "…[OK]\n",
    STOP_MS0012         => "2. Pacemaker 停止確認\n",
    STOP_MS0013         => "…[NG]\n",
    STOP_MS0014         => "Pacemaker および PostgreSQL の停止確認処理のタイムアウト時間([0]秒)を経過したのでスクリプトを終了します\n".
                           "ps コマンドを用いて Pacemaker および PostgreSQL のプロセスが正常に停止されているかを確認してください\n",
    STOP_MS0015         => "ノード([0])で Pacemaker を停止しました\n",
    STOP_MS0016         => "PG-REX の [0] ([1])を停止しました\n",
    STOP_MS0017         => "cib.xml に リソース ID \"[0]\" の \"pgdata\" の設定がないので PostgreSQL プロセス確認を行えません\n".
                           "既に PostgreSQL が停止している状態を前提に動作します\n",

    DBCHECK_USAGE  => <<_DBCHECK_USAGE_,

pg-rex_dbcluster_check version 1.2

PG-REX の状態を確認し、
Slave 起動時にベースバックアップの取得・展開が必要かどうかを確認するツール

Usage:pg-rex_dbcluster_check [-h]

    -h, --help      Usage を表示し終了します

_DBCHECK_USAGE_
    
    DBCHECK_MS0001      => "Ctrl+C は本プログラムでは無効です\n",
    DBCHECK_MS0002      => "**** 実行準備 ****\n",
    DBCHECK_MS0003      => "[0]. 環境設定ファイルの読み込みと両系のノード名を取得\n",
    DBCHECK_MS0005      => "…[OK]\n\n",
    DBCHECK_MS0006      => "[0]. 自身のノードで Pacemaker が停止していることを確認\n",
    DBCHECK_MS0007      => "…[NG]\n",
    DBCHECK_MS0008      => "自身のノードで Pacemaker が稼働しています\n",
    DBCHECK_MS0009      => "[0]. 相手先のノードで Master として既に起動していることを確認\n",
    DBCHECK_MS0011      => "相手先のノードで Master が稼働していません\n",
    DBCHECK_MS0012      => "**** ベースバックアップの取得・展開が必要かどうかを確認 ****\n",
    DBCHECK_MS0013      => "[0]. 初回起動でないことを確認\n",
    DBCHECK_MS0014      => "cib.xml ファイル \"[0]\" が存在しません\n",
    DBCHECK_MS0015      => "[0]. DB クラスタがあることを確認\n",
    DBCHECK_MS0017      => "PostgreSQL の設定ファイル \"[0]\" が存在しません\n",
    DBCHECK_MS0018      => "[0]. 起動禁止フラグがあることを確認\n",
    DBCHECK_MS0019      => "起動禁止フラグファイル \"[0]\" が存在します\n".
                           "起動禁止フラグが存在する場合、前回 Master で動作していた可能性があるため、\n".
                           "DB クラスタの取得・展開無しで Slave としてそのまま組み込むことができません\n",
    DBCHECK_MS0020      => "[0]. 両系の DB クラスタの状況を確認\n",
    DBCHECK_MS0021      => "自身のノードと相手のノードでデータベース識別子が異なっています ([0] != [1])\n",
    DBCHECK_MS0022      => "自身のノードの TimeLineID のほうが相手のノードの TimeLineID よりも大きくなっています ([0] > [1])\n",
    DBCHECK_MS0023      => "自身のノードの XLOG の位置のほうが相手のノードの XLOG の位置よりも進んでいます ([0] > [1])\n",
    DBCHECK_MS0024      => "自身のノードの TimeLineID の時系列履歴ファイル \"[0]\" が相手ノードの同ファイル名のファイルと内容が異なっています\n",
    DBCHECK_MS0025      => "相手ノードの TimeLineID の時系列履歴ファイル \"[0]\" に自身のノードの TimeLineID を通った履歴が残っていません\n",
    DBCHECK_MS0026      => "相手ノードの TimeLineID の時系列履歴ファイル \"[0]\" に自身のノードの TimeLineID の XLOG の位置を通った履歴が残っていません\n",
    DBCHECK_MS0027      => "Slave の起動時にベースバックアップの取得・展開が不要です\n".
                           "ただし、現在の DB クラスタは \"[0]\" 時点の DB クラスタです\n".
                           "この DB クラスタが非常に古い場合はベースバックアップを取得し直してください\n",
    DBCHECK_MS0028      => "Slave の起動時にベースバックアップの取得・展開が必要です\n",
    DBCHECK_MS0029      => "root@[0]'s password:",
    DBCHECK_MS0030      => "\nパスワードが入力されました\n",
    
    ARCHDELETE_USAGE  => <<_ARCDELETE_USAGE_,

pg-rex_archivefile_delete version 1.2

PG-REX 運用中に作成された、不要なアーカイブログを削除するツール

Usage:pg-rex_archivefile_delete [-m][-r][-f][-h][[Hostname:]BasebackupPath]

    -m, --move      mv モードで実行します
    -r, --remove    rm モードで実行します
       (mv モードまたは rm モードはどちらか片方を必ず指定すること)
    -f, --force     スクリプトの問い合わせ無しで実行します
    -h, --help      Usage を表示し終了します
    Hostname        ベースバックアップが存在するリモートサーバを指定します
    BasebackupPath  ベースバックアップの場所の絶対パスを指定します
        注) 指定したベースバックアップ以前に取得したベースバックアップは、
            アーカイブログが削除されてしまうため、使用することができなくなります

_ARCDELETE_USAGE_
    
    ARCHDELETE_MS0001   => "Ctrl+C は本プログラムでは無効です\n",
    ARCHDELETE_MS0002   => "mv モードか rm モードのどちらか片方を指定してください\n",
    ARCHDELETE_MS0003   => "\n**** 1. 実行準備 ****\n",
    ARCHDELETE_MS0004   => "mv モードで実行します\n",
    ARCHDELETE_MS0005   => "rm モードで実行します\n",
    ARCHDELETE_MS0006   => "バックアップパスのフォーマットが不正です : \"[0]\"\n",
    ARCHDELETE_MS0007   => "ベースバックアップが存在するリモートサーバを入力してください\n".
                           "(入力しなければ \"localhost\" を設定します)\n".
                           "> ",
    ARCHDELETE_MS0008   => "リモートサーバの入力が不正です : \"[0]\"\n",
    ARCHDELETE_MS0009   => "ベースバックアップの場所の絶対パスを入力してください\n".
                           "(入力しなければバックアップ指定無しとして実行されアーカイブが削除されるため、\n".
                           " 以前に取得したベースバックアップが使用できなくなります)\n".
                           "> ",
    ARCHDELETE_MS0010   => "ベースバックアップの場所の絶対パスの入力が不正です : \"[0]\"\n",
    ARCHDELETE_MS0011   => "リモートサーバ \"[0]\" 、ベースバックアップの場所 \"[1]\" を指定しました\n".
                           "よろしいでしょうか (y/N) : ",
    ARCHDELETE_MS0012   => "スクリプトを終了します\n",
    ARCHDELETE_MS0013   => "環境設定ファイルを読み込みます\n",
    ARCHDELETE_MS0015   => "両系のノード名を取得します\n",
    ARCHDELETE_MS0016   => "cib.xml ファイルを読み込みます\n",
    ARCHDELETE_MS0018   => "ベースバックアップの場所を指定せずに実行すると、\n".
                           "自身のノード \"[0]\" と相手先のノード \"[1]\" の\n".
                           "現時点の PGDATA \"[2]\" を基準にしてアーカイブログを削除することになります\n".
                           "アーカイブログを削除しますか (y/N) : ",
    ARCHDELETE_MS0019   => "\n**** 2. WAL ファイル名の取得 ****\n",
    ARCHDELETE_MS0020   => "指定されたバックアップからリカバリを行うために必要な最初の WAL ファイル名を取得します\n",
    ARCHDELETE_MS0021   => "ディレクトリ \"[0]\" が存在しません\n",
    ARCHDELETE_MS0022   => "バックアップラベルファイル \"[0]\" の一行目のフォーマットが正しくありません\n",
    ARCHDELETE_MS0023   => " \"[0]\" \n",
    ARCHDELETE_MS0024   => "自身のノード \"[0]\" の現時点の PGDATA \"[1]\" からリカバリに必要な最初の WAL ファイル名を取得します\n",
    ARCHDELETE_MS0025   => "pg_controldata の結果が空のためリカバリに必要な最初の WAL ファイル名を取得できません\n",
    ARCHDELETE_MS0026   => "相手先のノード \"[0]\" の現時点の PGDATA \"[1]\" からリカバリに必要な最初の WAL ファイル名を取得します\n",
    ARCHDELETE_MS0027   => "\n**** 3. 削除基準の算出 ****\n",
    ARCHDELETE_MS0028   => "削除基準がないためスクリプトを終了します\n",
    ARCHDELETE_MS0029   => "削除基準を \"[0]\" としました\n",
    ARCHDELETE_MS0030   => "\n**** 4. アーカイブログの削除 ****\n",
    ARCHDELETE_MS0031   => "アーカイブディレクトリ \"[0]\" の確認に失敗しました\n",
    ARCHDELETE_MS0032   => "削除対象のリストに \"[0]\" を追加します\n",
    ARCHDELETE_MS0033   => "削除対象のリストが空のためスクリプトを終了します\n",
    ARCHDELETE_MS0034   => "移動先ディレクトリ \"[0]\" が既に存在しています\n",
    ARCHDELETE_MS0035   => "移動先ディレクトリ \"[0]\" の作成に失敗しました\n",
    ARCHDELETE_MS0036   => "移動先ディレクトリ \"[0]\" の postgres ユーザへの変更に失敗しました\n",
    ARCHDELETE_MS0037   => "移動先ディレクトリ \"[0]\" を作成しました\n",
    ARCHDELETE_MS0038   => "ファイル \"[0]\" の移動に失敗しました\n",
    ARCHDELETE_MS0039   => " -- mv -- [0] \n",
    ARCHDELETE_MS0040   => "アーカイブログの移動に成功しました\n".
                           "mv モード実行のため、移動したファイルは \"[0]\" に格納されています\n",
    ARCHDELETE_MS0041   => "ファイル \"[0]\" の削除に失敗しました\n",
    ARCHDELETE_MS0042   => " -- rm -- [0] \n",
    ARCHDELETE_MS0043   => "アーカイブログの削除に成功しました\n",
    ARCHDELETE_MS0044   => "root@[0]'s password:",
    ARCHDELETE_MS0045   => "\nパスワードが入力されました\n",

    COMMON_MS0001       => "crm_mon の実行に失敗しました\n",
    COMMON_MS0003       => "cib.xml ファイルにリソース ID \"[0]\" の \"[1]\" のパラメータが存在していません\n",
    COMMON_MS0004       => "環境設定ファイルの [0] の指定がありません\n",
    COMMON_MS0005       => "環境設定ファイルの Archive_dir の設定は絶対パスで指定してください\n",
    COMMON_MS0006       => "環境設定ファイルの STONITH の設定は enable または disable で指定してください\n",
    COMMON_MS0007       => "環境設定ファイルの D-LAN_IPAddress の設定は2つの IP アドレスをカンマ区切りで指定してください\n",
    COMMON_MS0008       => "自身のマシンの IP アドレスの取得に失敗しました\n",
    COMMON_MS0009       => "環境設定ファイルの D-LAN_IPAddress の IP アドレスのいずれも自身のマシンに存在していません\n",
    COMMON_MS0010       => "環境設定ファイルの D-LAN_IPAddress の IP アドレスのいずれも相手先のマシンに存在していません\n",
    COMMON_MS0011       => "\"[0]\" のコマンドの実行に失敗しました\n",
    COMMON_MS0013       => "XLOG 位置の情報をパースできません\n",
    COMMON_MS0014       => "pg_controldata の値の取得に失敗しました\n",
    COMMON_MS0015       => "相手先のノード名の取得に失敗しました\n",
    COMMON_MS0016       => "相手先のノードへの ssh 接続に失敗しました\n",
    COMMON_MS0017       => "rsync コマンドの実行に失敗しました\n",
    COMMON_MS0018       => "scp コマンドの実行に失敗しました\n",
    COMMON_MS0019       => "bcast(ucast) の指定がない ha.cf が存在しています\n",
    COMMON_MS0020       => "node の指定がない ha.cf が存在しています\n",
    COMMON_MS0021       => "環境設定ファイルの VIP_SLAVE の設定は enable または disable で指定してください\n",
    COMMON_MS0022       => "環境設定ファイルの STONITH_ResourceID の設定は2つの IP アドレスをカンマ区切りで指定してください\n",
    COMMON_MS0023       => "cib.xml ファイル \"[0]\" の読み込みに失敗しました\n",
    COMMON_MS0024       => "環境設定ファイル \"[0]\" の読み込みに失敗しました\n",
    COMMON_MS0025       => "ha.cf ファイル \"[0]\" の読み込みに失敗しました\n",
    COMMON_MS0026       => "[0] ユーザで実行されているためスクリプトを終了いたします\n".
                           "root ユーザで再度実行してください\n",
};

1;
